==> react-molecule-select-1.9.0.tgz: package/lib/index.js <==
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
import _createClass from "@babel/runtime/helpers/createClass";
import _assertThisInitialized from "@babel/runtime/helpers/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { moleculeDropdownListSizes as SIZES } from '@s-ui/react-molecule-dropdown-list';
import MoleculeSelectSingleSelection from './components/SingleSelection';
import MoleculeSelectMultipleSelection from './components/MultipleSelection';
import { withOpenToggle } from '@s-ui/hoc';
import { getTarget } from '@s-ui/js/lib/react';
import { getCurrentElementFocused } from '@s-ui/js/lib/dom';
var BASE_CLASS = "sui-MoleculeSelect";
var CLASS_FOCUS = BASE_CLASS + "--focus";
var CLASS_DISABLED = "is-disabled";
var ERROR_STATES = {
  ERROR: 'error',
  SUCCESS: 'success'
};

var MoleculeSelect =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(MoleculeSelect, _Component);

  function MoleculeSelect() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.refMoleculeSelect = _this.props.refMoleculeSelect || React.createRef();
    _this.refsMoleculeSelectOptions = [];
    _this.state = {
      focus: false
    };

    _this.closeList = function (ev) {
      var onToggle = _this.props.onToggle;

      var _assertThisInitialize = _assertThisInitialized(_this),
          domMoleculeSelect = _assertThisInitialize.refMoleculeSelect.current;

      onToggle(ev, {
        isOpen: false
      });
      domMoleculeSelect.focus();
      ev.preventDefault();
      ev.stopPropagation();
    };

    _this.focusFirstOption = function (ev, _ref) {
      var options = _ref.options;
      options[0].focus();
      ev.preventDefault();
      ev.stopPropagation();
    };

    _this.handleToggle = function (ev) {
      var onToggle = _this.props.onToggle;
      onToggle(ev, {});
      ev.preventDefault();
      ev.stopPropagation();
    };

    _this.handleKeyDown = function (ev) {
      ev.persist();
      var isOpen = _this.props.isOpen;

      var _assertThisInitialize2 = _assertThisInitialized(_this),
          refMoleculeSelect = _assertThisInitialize2.refMoleculeSelect,
          refsMoleculeSelectOptions = _assertThisInitialize2.refsMoleculeSelectOptions,
          closeList = _assertThisInitialize2.closeList,
          focusFirstOption = _assertThisInitialize2.focusFirstOption,
          handleToggle = _assertThisInitialize2.handleToggle;

      var options = refsMoleculeSelectOptions.map(getTarget);
      var domSourceEvent = ev.target;
      var domMoleculeSelect = refMoleculeSelect.current;

      if (!isOpen) {
        if (['Enter', 'ArrowDown', 'ArrowUp'].includes(ev.key)) {
          if (domSourceEvent === domMoleculeSelect) handleToggle(ev);else closeList(ev);
        }
      } else {
        var currentElementFocused = getCurrentElementFocused();
        var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
        if (ev.key === 'Escape') closeList(ev);
        if (ev.key === 'ArrowDown' && !isSomeOptionFocused) focusFirstOption(ev, {
          options: options
        });
      }
    };

    _this.handleSelect = function () {
      _this.setState({
        focus: true
      });
    };

    _this.handleFocusIn = function () {
      var disabled = _this.props.disabled;
      !disabled && _this.setState({
        focus: true
      });
    };

    _this.handleFocusOut = function (ev) {
      ev.persist();

      var _assertThisInitialize3 = _assertThisInitialized(_this),
          refsMoleculeSelectOptions = _assertThisInitialize3.refsMoleculeSelectOptions,
          closeList = _assertThisInitialize3.closeList;

      var isOpen = _this.props.isOpen;
      var options = refsMoleculeSelectOptions.map(getTarget);
      var firstOption = options[0];
      setTimeout(function () {
        var currentElementFocused = getCurrentElementFocused();
        var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
        var isOptionListFocused = firstOption ? currentElementFocused.isSameNode(firstOption.parentNode) : false;

        if (!isSomeOptionFocused && !isOptionListFocused && isOpen) {
          closeList(ev);
        }
      }, 1);

      _this.setState({
        focus: false
      });
    };

    return _this;
  }

  var _proto = MoleculeSelect.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        multiselection = _this$props.multiselection,
        _props = _objectWithoutPropertiesLoose(_this$props, ["multiselection"]);

    var className = this.className,
        handleKeyDown = this.handleKeyDown,
        extendedChildren = this.extendedChildren,
        refMoleculeSelect = this.refMoleculeSelect,
        handleFocusIn = this.handleFocusIn,
        handleFocusOut = this.handleFocusOut;
    return React.createElement("div", {
      ref: refMoleculeSelect,
      tabIndex: "0",
      className: className,
      onKeyDown: handleKeyDown,
      onFocus: handleFocusIn,
      onBlur: handleFocusOut
    }, multiselection ? React.createElement(MoleculeSelectMultipleSelection, Object.assign({
      refMoleculeSelect: refMoleculeSelect
    }, _props), extendedChildren) : React.createElement(MoleculeSelectSingleSelection, Object.assign({
      refMoleculeSelect: refMoleculeSelect
    }, _props), extendedChildren));
  };

  _createClass(MoleculeSelect, [{
    key: "extendedChildren",
    get: function get() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          keysSelection = _this$props2.keysSelection; // eslint-disable-line react/prop-types

      var refsMoleculeSelectOptions = this.refsMoleculeSelectOptions;
      return React.Children.toArray(children).filter(Boolean).map(function (child, index) {
        refsMoleculeSelectOptions[index] = React.createRef();
        return React.cloneElement(child, {
          innerRef: refsMoleculeSelectOptions[index],
          onSelectKey: keysSelection
        });
      });
    }
  }, {
    key: "className",
    get: function get() {
      var _cx;

      var focus = this.state.focus;
      var disabled = this.props.disabled;
      var errorStateClass = this.errorStateClass;
      return cx(BASE_CLASS, (_cx = {}, _cx[CLASS_FOCUS] = focus, _cx[CLASS_DISABLED] = disabled, _cx), errorStateClass);
    }
  }, {
    key: "errorStateClass",
    get: function get() {
      var errorState = this.props.errorState;
      if (errorState) return BASE_CLASS + "--" + ERROR_STATES.ERROR;
      if (errorState === false) return BASE_CLASS + "--" + ERROR_STATES.SUCCESS;
      return '';
    }
  }]);

  return MoleculeSelect;
}(Component);

MoleculeSelect.defaultProps = {
  onChange: function onChange() {},
  onToggle: function onToggle() {},
  keysSelection: [' ', 'Enter'],
  disabled: false
};
export default withOpenToggle(MoleculeSelect);
export { SIZES as moleculeSelectDropdownListSizes };

==> react-molecule-select-1.10.0.tgz: package/lib/index.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import { moleculeDropdownListSizes as SIZES } from '@s-ui/react-molecule-dropdown-list';
import MoleculeSelectSingleSelection from './components/SingleSelection';
import MoleculeSelectMultipleSelection from './components/MultipleSelection';
import { withOpenToggle } from '@s-ui/hoc';
import { getTarget } from '@s-ui/js/lib/react';
import { getCurrentElementFocused } from '@s-ui/js/lib/dom';
var BASE_CLASS = "sui-MoleculeSelect";
var CLASS_FOCUS = BASE_CLASS + "--focus";
var CLASS_DISABLED = "is-disabled";
var ERROR_STATES = {
  ERROR: 'error',
  SUCCESS: 'success'
};

var MoleculeSelect =
/*#__PURE__*/
function (_Component) {
  _inheritsLoose(MoleculeSelect, _Component);

  function MoleculeSelect() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _Component.call.apply(_Component, [this].concat(args)) || this;
    _this.refMoleculeSelect = _this.props.refMoleculeSelect || React.createRef();
    _this.refsMoleculeSelectOptions = [];
    _this.state = {
      focus: false
    };

    _this.closeList = function (ev) {
      var onToggle = _this.props.onToggle;

      var _assertThisInitialize = _assertThisInitialized(_this),
          domMoleculeSelect = _assertThisInitialize.refMoleculeSelect.current;

      onToggle(ev, {
        isOpen: false
      });
      domMoleculeSelect.focus();
      ev.preventDefault();
      ev.stopPropagation();
    };

    _this.focusFirstOption = function (ev, _ref) {
      var options = _ref.options;
      options[0].focus();
      ev.preventDefault();
      ev.stopPropagation();
    };

    _this.handleToggle = function (ev) {
      var onToggle = _this.props.onToggle;
      onToggle(ev, {});
      ev.preventDefault();
      ev.stopPropagation();
    };

    _this.handleKeyDown = function (ev) {
      ev.persist();
      var isOpen = _this.props.isOpen;

      var _assertThisInitialize2 = _assertThisInitialized(_this),
          refMoleculeSelect = _assertThisInitialize2.refMoleculeSelect,
          refsMoleculeSelectOptions = _assertThisInitialize2.refsMoleculeSelectOptions,
          closeList = _assertThisInitialize2.closeList,
          focusFirstOption = _assertThisInitialize2.focusFirstOption,
          handleToggle = _assertThisInitialize2.handleToggle;

      var options = refsMoleculeSelectOptions.map(getTarget);
      var domSourceEvent = ev.target;
      var domMoleculeSelect = refMoleculeSelect.current;

      if (!isOpen) {
        if (['Enter', 'ArrowDown', 'ArrowUp'].includes(ev.key)) {
          if (domSourceEvent === domMoleculeSelect) handleToggle(ev);else closeList(ev);
        }
      } else {
        var currentElementFocused = getCurrentElementFocused();
        var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
        if (ev.key === 'Escape') closeList(ev);
        if (ev.key === 'ArrowDown' && !isSomeOptionFocused) focusFirstOption(ev, {
          options: options
        });
      }
    };

    _this.handleSelect = function () {
      _this.setState({
        focus: true
      });
    };

    _this.handleFocusIn = function () {
      var disabled = _this.props.disabled;
      !disabled && _this.setState({
        focus: true
      });
    };

    _this.handleFocusOut = function (ev) {
      ev.persist();

      var _assertThisInitialize3 = _assertThisInitialized(_this),
          refsMoleculeSelectOptions = _assertThisInitialize3.refsMoleculeSelectOptions,
          closeList = _assertThisInitialize3.closeList;

      var isOpen = _this.props.isOpen;
      var options = refsMoleculeSelectOptions.map(getTarget);
      var firstOption = options[0];
      setTimeout(function () {
        var currentElementFocused = getCurrentElementFocused();
        var isSomeOptionFocused = [].concat(options).includes(currentElementFocused);
        var isOptionListFocused = firstOption ? currentElementFocused.isSameNode(firstOption.parentNode) : false;

        if (!isSomeOptionFocused && !isOptionListFocused && isOpen) {
          closeList(ev);
        }
      }, 1);

      _this.setState({
        focus: false
      });
    };

    return _this;
  }

  var _proto = MoleculeSelect.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        multiselection = _this$props.multiselection,
        _props = _objectWithoutProperties(_this$props, ["multiselection"]);

    var className = this.className,
        handleKeyDown = this.handleKeyDown,
        extendedChildren = this.extendedChildren,
        refMoleculeSelect = this.refMoleculeSelect,
        handleFocusIn = this.handleFocusIn,
        handleFocusOut = this.handleFocusOut;
    return React.createElement("div", {
      ref: refMoleculeSelect,
      tabIndex: "0",
      className: className,
      onKeyDown: handleKeyDown,
      onFocus: handleFocusIn,
      onBlur: handleFocusOut
    }, multiselection ? React.createElement(MoleculeSelectMultipleSelection, Object.assign({
      refMoleculeSelect: refMoleculeSelect
    }, _props), extendedChildren) : React.createElement(MoleculeSelectSingleSelection, Object.assign({
      refMoleculeSelect: refMoleculeSelect
    }, _props), extendedChildren));
  };

  _createClass(MoleculeSelect, [{
    key: "extendedChildren",
    get: function get() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          keysSelection = _this$props2.keysSelection; // eslint-disable-line react/prop-types

      var refsMoleculeSelectOptions = this.refsMoleculeSelectOptions;
      return React.Children.toArray(children).filter(Boolean).map(function (child, index) {
        refsMoleculeSelectOptions[index] = React.createRef();
        return React.cloneElement(child, {
          innerRef: refsMoleculeSelectOptions[index],
          onSelectKey: keysSelection
        });
      });
    }
  }, {
    key: "className",
    get: function get() {
      var _cx;

      var focus = this.state.focus;
      var disabled = this.props.disabled;
      var errorStateClass = this.errorStateClass;
      return cx(BASE_CLASS, (_cx = {}, _cx[CLASS_FOCUS] = focus, _cx[CLASS_DISABLED] = disabled, _cx), errorStateClass);
    }
  }, {
    key: "errorStateClass",
    get: function get() {
      var errorState = this.props.errorState;
      if (errorState) return BASE_CLASS + "--" + ERROR_STATES.ERROR;
      if (errorState === false) return BASE_CLASS + "--" + ERROR_STATES.SUCCESS;
      return '';
    }
  }]);

  return MoleculeSelect;
}(Component);

MoleculeSelect.defaultProps = {
  disabled: false,
  keysSelection: [' ', 'Enter'],
  onChange: function onChange() {},
  onToggle: function onToggle() {},
  readOnly: false
};
export default withOpenToggle(MoleculeSelect);
export { SIZES as moleculeSelectDropdownListSizes };
